﻿using System;
using Racelogic.LabSat3WBAPI;
using System.Threading;
using LS3 = Racelogic.LabSatAPI;

namespace Racelogic.LabSatAPITest.CodeSamples
{

    public class CSharpLS3WB
    {

        private string ipaddress = "192.168.1.149";
        private string filename = "APITestScenario";

        public void RunCodeSamples()
        {

            ConfigPlay();

            Media();

            Record();

            PlayStart();

            Attenuation();

            Mute();

            PlayStop();

            Monitor();

            ConfigSetup();


        }


        private void Record()
        {
            //record
            var cmd = new RecordCommand(ipaddress);
            cmd.Execute(new LS3.RecordCommandParams() { FileName = filename });


            //record for 20s
            cmd.Execute(new LS3.RecordCommandParams() { FileName = filename, RecordForSeconds = 20 });

            //wait for 10s then stop
            Thread.Sleep(10000);

            //record stop
            cmd.Execute(new LS3.RecordCommandParams() { Stop = true });

        }


        private void PlayStart()
        {
            //play
            var cmd = new PlayCommand(ipaddress);
            cmd.Execute(new LS3.PlayCommandParams() { FileName = filename });

            //stop
            cmd = new PlayCommand(ipaddress);
            cmd.Execute(new LS3.PlayCommandParams() { Stop = true });

            Thread.Sleep(200);

            //play from for
            cmd = new PlayCommand(ipaddress);
            cmd.Execute(new LS3.PlayCommandParams() { FileName = filename, FromSeconds = 0.1, PlayForSeconds = 10 });

        }
        private void PlayStop()
        {

            //stop
            var cmd = new PlayCommand(ipaddress);
            cmd.Execute(new LS3.PlayCommandParams() { Stop = true });

        }

        private void Attenuation()
        {
            //attenuation apply to all channels
            var cmd = new AttenuationCommand(ipaddress);
            cmd.Execute(new AttenuationCommandParams() { AttenuationLevel = 10 });

            //attenuation to specific channels
            cmd.Execute(new AttenuationCommandParams() { SetCh1 = true, SetCh3 = true, AttenuationLevel = 10 });

        }

        private void Mute()
        {
            var cmd = new MuteCommand(ipaddress);

            //mute all channels
            cmd.Execute(new MuteCommandParams() { Mute = true });

            cmd.Execute(new MuteCommandParams() { Mute = false });

            //mute individual channels
            cmd.Execute(new MuteCommandParams() { Mute = true, SetCh1 = true, SetCh2 = true });

            cmd.Execute(new MuteCommandParams() { Mute = false, SetCh1 = true, SetCh2 = false, SetCh3 = true });

            cmd.Execute(new MuteCommandParams() { Mute = true, SetCh1 = true, SetCh3 = true });

        }



        private void ConfigDisplay()
        {
            var cmd = new ConfigCommand(ipaddress);

            //brightness
            cmd.Execute(new LS3.ConfigSetupDisplayCommandParameters() { Brightness = 91 });

            //contrast
            cmd.Execute(new LS3.ConfigSetupDisplayCommandParameters() { Contrast = 80 });

            //brightness and contrast
            cmd.Execute(new LS3.ConfigSetupDisplayCommandParameters() { Brightness = 52, Contrast = 50 });
        }


        private void ConfigPlay()
        {
            var cmd = new ConfigCommand(ipaddress);

            //Pause and loop commands should be run separately

            //pause
            cmd.Execute(new ConfigPlayCommandParameters() { PauseBeforeLoop = 123 });

            //loop = N
            cmd.Execute(new ConfigPlayCommandParameters() { Loop = false });

        }
        private void ConfigSetup()
        {
            var cmd = new ConfigCommand(ipaddress);

            //power saving mode
            cmd.Execute(new ConfigSetupCommandParameters() { PowerSavingMode = true });

            cmd.Execute(new ConfigSetupCommandParameters() { PowerSavingMode = false });

            //configure constellations
            #region config constellations

            //1 frequency
            cmd.Execute(new ConfigConstellationCommandParameters() { Quantization = Quantization._3, Bandwidth = Bandwith._56, Frequency1 = 1583});

            //2 frequencies
            cmd.Execute(new ConfigConstellationCommandParameters() { Quantization = Quantization._2, Bandwidth = Bandwith._56, Frequency1 = 1583, Frequency2 = 1227});

            //3 frequencies
            cmd.Execute(new ConfigConstellationCommandParameters() { Quantization = Quantization._1, Bandwidth = Bandwith._56, Frequency1 = 1583, Frequency2 = 1229, Frequency3 = 1173 });

            #endregion

            //config clock / time
            #region config clock / time
            //external ref
            cmd.Execute(new ConfigSetupCommandParameters() { SetExternalRef = ClockReference.EXT });

            cmd.Execute(new ConfigSetupCommandParameters() { SetExternalRef = ClockReference.TCXO });

            //OCXO
            cmd.Execute(new ConfigSetupCommandParameters() { SetExternalRef = ClockReference.OCXO });

            //use utc time
            cmd.Execute(new ConfigSetupCommandParameters() { UseUTCTime = true });

            //manually set time
            cmd.Execute(new ConfigSetupCommandParameters() { SetTimeOnDevice = new DateTime(2014, 04, 22, 12, 11, 10) });

            //cannot have manual and utc time
            cmd.Execute(new ConfigSetupCommandParameters() { UseUTCTime = true, SetTimeOnDevice = new DateTime(2014, 04, 22, 12, 11, 10) });
            #endregion

            //config digital channels
            #region config digital channels

            cmd.Execute(new ConfigSetupCommandParameters() { Channel2DigitalRecordMode = ChannelDigitalRecordMode.OFF, Channel4DigitalRecordMode = ChannelDigitalRecordMode.OFF });

            cmd.Execute(new ConfigSetupCommandParameters() { Channel3DigitalRecordMode = ChannelDigitalRecordMode.CAN2 });

            cmd.Execute(new ConfigSetupCommandParameters() { Channel1DigitalRecordMode = ChannelDigitalRecordMode.DIG2, Channel3DigitalRecordMode = ChannelDigitalRecordMode.RS232 });

            cmd.Execute(new ConfigSetupCommandParameters() { Channel2DigitalRecordMode = ChannelDigitalRecordMode.OFF });

            #endregion

            //Config setup CAN
            #region Config setup CAN

            //Set baud rate on CAN Channel 1
            cmd.Execute(new ConfigSetupCanCommandParameters() { Channel1BaudRate = "K9600" });

            //Set baud rate on CAN Channel 2
            cmd.Execute(new ConfigSetupCanCommandParameters() { Channel2BaudRate = "M15" });

            //Silent Record
            cmd.Execute(new ConfigSetupCanCommandParameters() { SilentRecording = true });

            cmd.Execute(new ConfigSetupCanCommandParameters() { SilentRecording = false });

            //Enable CAN replay
            cmd.Execute(new ConfigSetupCanCommandParameters() { ReplayFile = true });
            cmd.Execute(new ConfigSetupCanCommandParameters() { ReplayFile = false });

            //Enable CAN logging
            cmd.Execute(new ConfigSetupCanCommandParameters() { LogFile = true });

            cmd.Execute(new ConfigSetupCanCommandParameters() { LogFile = false });

            #endregion

        }


        private void Monitor()
        {
            var cmd = new MonitorCommand(ipaddress);

            //set monitor nmea
            cmd.Execute(new MonitorCommandParams() { NMEAOutput = true });

            cmd.Execute(new MonitorCommandParams() { NMEAOutput = false });

            //set CMO
            cmd.Execute(new MonitorCommandParams() { CNO = true });
            //set  monitor location
            cmd.Execute(new MonitorCommandParams() { Location = true });
            //example of setting muliple params at the same time.
            cmd.Execute(new MonitorCommandParams() { Location = true, CNO = true });

        }

        private void Media()
        {
            var cmd = new MediaCommand(ipaddress);

            //list command
            cmd.Execute(new MediaCommandParams() { ListDirectoriesAndFiles = true });
            Console.WriteLine(cmd.OutputText);

            //change directory
            cmd.Execute(new MediaCommandParams() { ChangeDirectoryTo = "New Folder(1)" });

            //go up one directory
            cmd.Execute(new MediaCommandParams() { ChangeDirectoryUpOneLevel = true });

            //Sent directory to route
            cmd.Execute(new MediaCommandParams() { ChangeDirectoryToRoot = true });

            //delete file
            cmd.Execute(new MediaCommandParams() { DeleteFileWithName = "scenario1" });
        }


    }
}
